@@ -85,7 +85,11 @@ def parse_complete_tag(x: DockerCompleteImageName) -> BuildResult:
 
     try:
         return BuildResult(
-            registry=registry, organization=organization, repository=repository, tag=tag, digest=digest,
+            registry=registry,
+            organization=organization,
+            repository=repository,
+            tag=tag,
+            digest=digest,
         )
     except ValueError as e:
         raise ValueError(x) from e
