@@ -100,7 +100,17 @@ def get_branch(dirname: str) -> str:
 
 
 def get_head_tag(dirname: str) -> Optional[str]:
-    head_tag = _run_cmd(["git", "-C", dirname, "describe", "--exact-match", "--tags", "HEAD",])
+    head_tag = _run_cmd(
+        [
+            "git",
+            "-C",
+            dirname,
+            "describe",
+            "--exact-match",
+            "--tags",
+            "HEAD",
+        ]
+    )
 
     head_tag = head_tag[0] if head_tag else None
     return head_tag
