@@ -65,13 +65,27 @@ import sys
 import json
 import time
 
-try:
-    from pip import get_installed_distributions
-except:
-    from pip._internal.utils.misc import get_installed_distributions
+
+
+def _get_installed_distributions(
+    local_only: bool = True,
+    user_only: bool = False,
+    paths=None,
+):
+    from pip._internal.metadata import get_environment
+    from pip._internal.metadata.pkg_resources import Distribution as _Dist
+
+    env = get_environment(paths)
+    dists = env.iter_installed_distributions(
+        local_only=local_only,
+        user_only=user_only,
+        skip=[],
+    )
+    return [ dist._dist for dist in dists]
+
 
 packages = {}
-for i in get_installed_distributions(local_only=False):
+for i in _get_installed_distributions(local_only=False):
     #print(i.__dict__)
 
     pkg = {
