@@ -7,6 +7,9 @@ __all__ = [
     "DockerTag",
     "DockerImageDigest",
     "DockerCompleteImageName",
+    "DockerUsername",
+    "DockerImageID",
+    "DockerSecret",
 ]
 
 DockerRegistryName = NewType("DockerCompleteImageName", str)
@@ -16,4 +19,7 @@ DockerRepositoryName = NewType("DockerRepositoryName", str)
 DockerTag = NewType("DockerTag", str)
 DockerImageDigest = NewType("DockerImageDigest", str)
 
+DockerImageID = NewType("DockerImageID", str)
 DockerCompleteImageName = NewType("DockerCompleteImageName", str)
+DockerUsername = NewType("DockerUsername", str)
+DockerSecret = NewType("DockerSecret", str)
