@@ -28,7 +28,7 @@ def update_versions(fn="requirements.txt", out="requirements.resolved"):
     with open(fn) as fd:
         req: Requirement
         for req in requirements.parse(fd):
-            todo = len(req.specs) == 0 or (len(req.specs) == 1 and req.specs[0] == ">=")
+            todo = (len(req.specs) == 0) or (len(req.specs) == 1 and req.specs[0][0] in (">=", ">"))
             if todo:
                 v = get_last_version_fresh(req.name)
                 if v is None:
@@ -38,7 +38,7 @@ def update_versions(fn="requirements.txt", out="requirements.resolved"):
                 logger.debug(f"Updated package   {req.name} to {v}")
                 req.specs = [("==", v)]
             else:
-                logger.debug(f"skipping spec {req}")
+                logger.debug(f"skipping spec {req}", specs=req.specs)
 
             ss = ",".join(f"{a}{b}" for a, b in req.specs)
             s2 = f"{req.name}{ss}"
