@@ -4,6 +4,7 @@ import os
 import subprocess
 import sys
 import traceback
+from json import JSONDecodeError
 from typing import Dict, Optional
 
 import requests
@@ -16,6 +17,7 @@ from .commons import get_dir_info
 __all__ = ["aido_check_need_upload_main", "get_last_version_fresh"]
 
 
+# noinspection PyUnresolvedReferences
 def download_json(url: str, headers: Dict[str, str] = None):
     headers = headers or {}
 
